@@ -26,7 +26,7 @@
 
 #include "vcp/persistent_capabilities.h"
 
-#include "i2c/i2c_bus_core.h"
+#include "i2c/i2c_execute.h"
 
 #include "ddc/ddc_displays.h"
 #include "ddc/ddc_services.h"
@@ -72,6 +72,8 @@ void app_interrogate(Parsed_Cmd * parsed_cmd)
    parsed_cmd->stats_types = DDCA_STATS_ALL;
    f0printf(fout(), "Forcing --disable-capabilities-cache\n");
    enable_capabilities_cache(false);
+   f0printf(fout(), "Forcing --force-slave-address..\n");
+   i2c_forceable_slave_addr_flag = true;
    f0printf(fout(), "This command will take a while to run...\n\n");
 
    ddc_ensure_displays_detected();    // *** ???
