@@ -88,7 +88,6 @@ app_set_vcp_value(
       bool              force)
 {
    assert(new_value && strlen(new_value) > 0);
-   FILE * errf = ferr();   // at app level will always be stderr()
    bool debug = false;
    DBGTRC_STARTING(debug,TRACE_GROUP, "feature=0x%02x, new_value=%s, value_type=%s, force=%s",
                 feature_code, new_value, setvcp_value_type_name(value_type), sbool(force));
@@ -102,23 +101,20 @@ app_set_vcp_value(
 
    dfm = dyn_get_feature_metadata_by_dh(feature_code,dh, (force || feature_code >= 0xe0) );
    if (!dfm) {
-      f0printf(errf, "Unrecognized VCP feature code: 0x%02x\n", feature_code);
-      ddc_excp = errinfo_new2(DDCRC_UNKNOWN_FEATURE, __func__,
+      ddc_excp = errinfo_new(DDCRC_UNKNOWN_FEATURE, __func__,
                               "Unrecognized VCP feature code: 0x%02x", feature_code);
       goto bye;
    }
 
    if (!(dfm->feature_flags & DDCA_WRITABLE)) {
-      f0printf(errf, "Feature 0x%02x (%s) is not writable\n", feature_code, dfm->feature_name);
-      ddc_excp = errinfo_new2(DDCRC_INVALID_OPERATION, __func__,
+      ddc_excp = errinfo_new(DDCRC_INVALID_OPERATION, __func__,
                  "Feature 0x%02x (%s) is not writable", feature_code, dfm->feature_name);
       goto bye;
    }
 
    if (dfm->feature_flags & DDCA_TABLE) {
       if (value_type != VALUE_TYPE_ABSOLUTE) {
-         f0printf(errf, "Relative VCP values valid only for Continuous VCP features\n");
-         ddc_excp = errinfo_new2(DDCRC_INVALID_OPERATION, __func__,
+         ddc_excp = errinfo_new(DDCRC_INVALID_OPERATION, __func__,
                                  "Relative VCP values valid only for Continuous VCP features");
          goto bye;
       }
@@ -126,8 +122,7 @@ app_set_vcp_value(
       Byte * value_bytes;
       int bytect = hhs_to_byte_array(new_value, &value_bytes);
       if (bytect < 0) {    // bad hex string
-         f0printf(errf, "Invalid hex value\n");
-         ddc_excp = errinfo_new2(DDCRC_ARG, __func__, "Invalid hex value");
+         ddc_excp = errinfo_new(DDCRC_ARG, __func__, "Invalid hex value");
          goto bye;
       }
 
@@ -140,16 +135,14 @@ app_set_vcp_value(
    else {  // the usual non-table case
       good_value = parse_vcp_value(new_value, &itemp);
       if (!good_value) {
-         f0printf(errf, "Invalid VCP value: %s\n", new_value);
          // what is better status code?
-         ddc_excp = errinfo_new2(DDCRC_ARG, __func__,  "Invalid VCP value: %s", new_value);
+         ddc_excp = errinfo_new(DDCRC_ARG, __func__,  "Invalid VCP value: %s", new_value);
          goto bye;
       }
 
       if (value_type != VALUE_TYPE_ABSOLUTE) {
          if ( !(dfm->feature_flags & DDCA_CONT) ) {
-            f0printf(errf, "Relative VCP values valid only for Continuous VCP features\n");
-            ddc_excp = errinfo_new2(DDCRC_INVALID_OPERATION, __func__,
+            ddc_excp = errinfo_new(DDCRC_INVALID_OPERATION, __func__,
                            "Relative VCP values valid only for Continuous VCP features");
             goto bye;
          }
@@ -163,12 +156,7 @@ app_set_vcp_value(
                        &parsed_response);
          if (ddc_excp) {
             ddcrc = ERRINFO_STATUS(ddc_excp);
-            // is message needed?
-            f0printf(errf, "Getting value failed for feature %02x. rc=%s\n",
-                           feature_code, psc_desc(ddcrc));
-            if (ddcrc == DDCRC_RETRIES)
-               f0printf(errf, "    Try errors: %s\n", errinfo_causes_string(ddc_excp));
-            ddc_excp = errinfo_new_with_cause3(ddcrc, ddc_excp, __func__,
+            ddc_excp = errinfo_new_with_cause(ddcrc, ddc_excp, __func__,
                           "Getting value failed for feature %02x, rc=%s",
                           feature_code, psc_desc(ddcrc));
             goto bye;
@@ -199,10 +187,10 @@ app_set_vcp_value(
    if (ddc_excp) {
       ddcrc = ERRINFO_STATUS(ddc_excp);
       if (ddcrc == DDCRC_VERIFY)
-         ddc_excp = errinfo_new_with_cause3(ddcrc, ddc_excp, __func__,
+         ddc_excp = errinfo_new_with_cause(ddcrc, ddc_excp, __func__,
                        "Verification failed for feature %02x", feature_code);
       else
-         ddc_excp = errinfo_new_with_cause3(ddcrc, ddc_excp, __func__,
+         ddc_excp = errinfo_new_with_cause(ddcrc, ddc_excp, __func__,
                        "Setting value failed for feature %02x, rc=%s",
                        feature_code, psc_desc(ddcrc));
    }
