@@ -3,7 +3,7 @@
  *  Primary file for the ENVIRONMENT command
  */
 
-// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2023 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 // #define SYSENV_QUICK_TEST_RUN 1
@@ -47,6 +47,7 @@
 #include "base/parms.h"
 #include "base/rtti.h"
 
+#include "i2c/i2c_execute.h"   // for i2c_forceable_slave_addr_flag
 #include "i2c/i2c_sysfs.h"
 
 #include "ddc/ddc_displays.h"     // for ddc_ensure_displays_detected()
@@ -248,6 +249,17 @@ static void query_packages() {
 #endif
 
 
+static void execute_cmd(int depth, const char * cmd) {
+   char * msgbuf = g_strdup_printf("Executing: %s", cmd);
+   rpt_label(depth, msgbuf);
+   free(msgbuf);
+   // bool ok =
+   execute_shell_cmd_rpt(cmd, depth+1);
+   // if (!ok)
+   //    rpt_label(depth, "Command failed");
+}
+
+
 /* Performs checks specific to the nvidia and fglrx proprietary video drivers.
  *
  * Arguments:
@@ -265,6 +277,8 @@ static void driver_specific_tests(struct driver_name_node * driver_list) {
       rpt_vstring(0,"Checking for special settings for proprietary Nvidia driver ");
       rpt_vstring(0,"(Needed for some newer Nvidia cards).");
       execute_shell_cmd_rpt("grep -iH i2c /etc/X11/xorg.conf /etc/X11/xorg.conf.d/*", 1);
+      execute_cmd(1,"grep -iH nvidia modprobe.conf modprobe.d/*");
+      execute_cmd(1,"grep RegistryDwords /proc/driver/nvidia/params");
    }
 
    if (driver_name_list_find_prefix(driver_list, "fglrx")) {
@@ -735,6 +749,8 @@ void query_sysenv() {
       rpt_label(0, "Set environment variable SYSENV_QUICK_TEST to skip some long-running tests.");
    }
 
+   i2c_forceable_slave_addr_flag = true;    // be a bully
+
    ddc_ensure_displays_detected();
    DBGTRC_NOPREFIX(debug, TRACE_GROUP, "display detection complete");
    device_xref_init();
@@ -746,8 +762,7 @@ void query_sysenv() {
       rpt_nl();
    }
 
-   if (output_level >= DDCA_OL_VV) {
-      DBGTRC_NOPREFIX(debug, TRACE_GROUP, "--VV only output: report_build_options()");
+   if (output_level >= DDCA_OL_VERBOSE) {
       report_build_options(0);
       rpt_nl();
    }
