@@ -47,9 +47,9 @@ typedef enum {
 typedef enum {
    CMD_FLAG_DDCDATA                = 0x0001,
    CMD_FLAG_FORCE                  = 0x0002,
-#ifdef OLD
+// #ifdef OLD
    CMD_FLAG_FORCE_SLAVE_ADDR       = 0x0004,  // UNUSED --force-slave-address
-#endif
+// #endif
    CMD_FLAG_TIMESTAMP_TRACE        = 0x0008,  // prepend trace and debug msgs with elapsed time
    CMD_FLAG_SHOW_UNSUPPORTED       = 0x0010,
    CMD_FLAG_ENABLE_FAILSIM         = 0x0020,
@@ -86,7 +86,11 @@ typedef enum {
 // CMD_FLAG_CLEAR_PERSISTENT_CACHE
 //                           = 0x1000000000,
    CMD_FLAG_WALLTIME_TRACE   = 0x2000000000,
+#ifdef ENABLE_SYSLOG
    CMD_FLAG_SYSLOG           = 0x4000000000,
+#endif
+   CMD_FLAG_I2C_IO_FILEIO  = 0x010000000000,
+   CMD_FLAG_I2C_IO_IOCTL   = 0x020000000000,
 } Parsed_Cmd_Flags;
 
 typedef
